<?php
/**
 * Class PostSaver_Ajax_Functions - class-postsaverplugin-ajax-functions.php
 *
 * @author   Jake Evans
 * @category Admin
 * @package  Includes
 * @version  6.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'PostSaver_Ajax_Functions', false ) ) :
	/**
	 * PostSaver_Ajax_Functions class. Here we'll do things like enqueue scripts/css, set up menus, etc.
	 */
	class PostSaver_Ajax_Functions {

		/**
		 * Class Constructor - Simply calls the Translations
		 */
		public function __construct() {


		}

		

		function postsaver_add_new_user_action_callback(){
			global $wpdb;
			
			check_ajax_referer( 'postsaver_add_new_user_action_callback', 'security' );

			if ( isset( $_POST['firstname'] ) ) {
				$firstname = sanitize_text_field($_POST['firstname'] );
			}

			if ( isset( $_POST['lastname'] ) ) {
				$lastname = sanitize_text_field($_POST['lastname'] );
			}

			if ( isset( $_POST['password'] ) ) {
				$password = sanitize_text_field($_POST['password'] );
			}

			if ( isset( $_POST['email'] ) ) {
				$email = sanitize_email( $_POST['email'] );
			}

			if ( isset( $_POST['postid'] ) ) {
				$postid = sanitize_text_field( $_POST['postid'] );
			}

			// Save a post ID to the user, in case they're registering for the first time from clicking on a "save this post" link.
			if ( ( false === $postid ) || ( 'false' === $postid ) || ( null === $postid ) ) {
				$postid = null;
			} else {
				$postid = $postid . ',';
			}

			// Check and see if a WordPress User already exists with this email.
			$email_flag = false;
			if( false !== email_exists( $email ) ){
				$email_flag = true;
			}
        	
        	if ( $email_flag ) {
				wp_die( 'Whoops! There\'s already a user registered with this Email Address!' );
			} else {
				$exact_time = time();
	        	$wp_user_id = wp_create_user( $firstname . '-' . $lastname . '-' . $exact_time , $password, $email );

				// WP User object
				$wp_user = new WP_User( $wp_user_id );

				$display_name_change_result = wp_update_user( array( 
					'ID' => $wp_user_id,
					'display_name' => $firstname . ' ' . $lastname,
					'first_name' => $firstname,
					'last_name' => $lastname,
				) );

				// Set the role of this user to subscriber.
				$wp_user->set_role( 'subscriber' );

				// Now add the user to our custom table, if WordPress user creation was successful.
				if ( ! is_wp_error( $wp_user_id ) ) {
					// Building array to add to DB.
					$db_insert_array = array(
						'firstname' =>  $firstname,
						'lastname' =>  $lastname,
						'email' =>  $email,
						'wpuserid' =>  $wp_user_id,
						'savedposts' => $postid,
					);

					// Building mask array to add to DB.
					$db_mask_insert_array = array(
						'%s',
						'%s',
						'%s',
						'%s',
						'%s',
					);

					$table_name = $wpdb->prefix . 'postsaver_users';
					$result = $wpdb->insert(  $table_name, $db_insert_array, $db_mask_insert_array );
					$lastid = $wpdb->insert_id;
				}

				wp_die( $firstname . '-' . $lastname . '-' . $exact_time );
			}
		}

		// Function to save the general settings on the "wp-admin/admin.php?page=PostSaver-Options-settings" page.
		function postsaver_settings_save_action_callback(){
			global $wpdb;
			check_ajax_referer( 'postsaver_settings_save_action_callback', 'security' );

			if ( isset( $_POST['dashboardurl'] ) ) {
				$dashboardurl = get_permalink( (int) filter_var($_POST['dashboardurl'],FILTER_SANITIZE_NUMBER_INT) );
			}

			if ( isset( $_POST['blogpageurl'] ) ) {
				$blogpageurl = get_permalink( (int) filter_var($_POST['blogpageurl'],FILTER_SANITIZE_NUMBER_INT) );
			}

			$table_name = $wpdb->prefix . 'postsaver_settings';
	        	
        	// Building array to add to DB.
        	$db_insert_array = array(
        		'dashboardurl' =>  $dashboardurl,
        		'blogpageurl' =>  $blogpageurl,
        	);

        	$result = $wpdb->update( $table_name, $db_insert_array, array( 'ID' => 1 ) );

        	wp_die( $result );
		}






















	}

endif;



