<?php
/**
 * Class PostSaver_General_Functions - class-toplevel-general-functions.php
 *
 * @author   Jake Evans
 * @category Admin
 * @package  Includes
 * @version  6.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'PostSaver_General_Functions', false ) ) :
	/**
	 * PostSaver_General_Functions class. Here we'll do things like enqueue scripts/css, set up menus, etc.
	 */
	class PostSaver_General_Functions {

		/**
		 *  Function that calls the Style and Scripts needed for displaying of admin pointer messages.
		 */
		public function postsaver_jre_admin_pointers_javascript() {
			wp_enqueue_style( 'wp-pointer' );
			wp_enqueue_script( 'wp-pointer' );
			wp_enqueue_script( 'utils' );
		}

		/**
		 *  Functions that loads up all menu pages/contents, etc.
		 */
		public function postsaver_jre_admin_page_function() {
			global $wpdb;
			require_once POSTSAVER_ROOT_INCLUDES_UI . 'class-admin-master-ui.php';
		}

		/**
		 * Function to automatically create a page upon activation for the default User Dashboard
		 */
		public function postsaver_create_initial_dashboard_page(){

			// Seeing if a post with our very custom meta key exists - if so, we don't need to make this page again.
			global $wpdb;
			$hasdata = $wpdb->get_results("select * from $wpdb->postmeta where meta_key='_postsaver_default_dashboard_page'");

			if ( 0 === count( $hasdata ) ) {
			    // Create post object.
				$my_post = array(
				  'post_title'    => wp_strip_all_tags( 'Your Saved Posts' ),
				  'post_content'  => '[postsaver_login_shortcode]',
				  'post_status'   => 'publish',
				  'post_author'   => 1,
				  'post_type'     => 'page',
				);

				// Insert the post into the database
				$postid = wp_insert_post( $my_post );

				// Add custom meta data to the post so we can determine whether this page does or does not already exist!
				add_post_meta( $postid, '_postsaver_default_dashboard_page', get_permalink( $postid ), true);

				// Now let's add this URL to the default settings table, if it's currently blank, for first-time installs or those that haven't set the dashboard URL on the general settings page.
				$table_name = $wpdb->prefix . 'postsaver_settings';
				$allgeneralsettings = $wpdb->get_row( "SELECT * from $table_name" );
				if ( ( '' === $allgeneralsettings->dashboardurl ) || ( null === $allgeneralsettings->dashboardurl ) ) {
					$insert_array = array(
						'dashboardurl' => get_permalink( $postid ),
					);
					$wpdb->update( $table_name, $insert_array, array( 'ID'=>1 ) );
				}

			}

			
		}


		/**
		 *  Function that saves the main dashboard URL as a constant.
		 */
		public function postsaver_dashboard_url_constant() {
			global $wpdb;
			// get the post ID from DB
			$table = $wpdb->prefix . 'postsaver_settings';
			$result = $wpdb->get_row( "SELECT * from $table WHERE ID = 1" );
			define( 'POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL', $result->dashboardurl );
		}

	




		/**
		 *  Function that logs in a user automatically after they've first registered.
		 */
		public function postsaver_autologin_after_registering() {

			if ( false !== stripos( $_SERVER['REQUEST_URI'], '?un=' ) ) {

				$username = sanitize_user( $_GET['un'] );
				$user     = get_user_by( 'login', $username );

				// Redirect URL.
				if ( ! is_wp_error( $user ) ) {
					clean_user_cache( $user->ID );
					wp_clear_auth_cookie();
					wp_set_current_user($user->ID);
					wp_set_auth_cookie( $user->ID, true, false );
					update_user_caches( $user );
				}
			}
		}

		/** Functions that loads up the menu page entry for this Extension.
		 *
		 *  @param array $submenu_array - The array that contains submenu entries to add to.
		 */
		public function postsaver_jre_my_admin_menu() {
			add_menu_page( 'Bell  PostSaver', 'PostSaver', 'manage_options', 'PostSaver-Options', array( $this, 'postsaver_jre_admin_page_function' ), POSTSAVER_ROOT_IMG_URL . 'savethispost.png', 6 );

			$submenu_array = array(
				'Settings',
			);

			// Filter to allow the addition of a new subpage.
			if ( has_filter( 'toplevel_add_sub_menu' ) ) {
				$submenu_array = apply_filters( 'toplevel_add_sub_menu', $submenu_array );
			}

			foreach ( $submenu_array as $key => $submenu ) {
				$menu_slug = strtolower( str_replace( ' ', '-', $submenu ) );
				add_submenu_page( 'PostSaver-Options', 'PostSaver', $submenu, 'manage_options', 'PostSaver-Options-' . $menu_slug, array( $this, 'postsaver_jre_admin_page_function' ) );
			}

			remove_submenu_page( 'PostSaver-Options', 'PostSaver-Options' );
		}

		/**
		 *  Here we take the Constant defined in postsaverplugin.php that holds the values that all our nonces will be created from, we create the actual nonces using wp_create_nonce, and the we define our new, final nonces Constant, called WPPLUGIN_FINAL_NONCES_ARRAY.
		 */
		public function postsaver_create_nonces() {

			$temp_array = array();
			foreach ( json_decode( POSTSAVER_NONCES_ARRAY ) as $key => $noncetext ) {
				$nonce              = wp_create_nonce( $noncetext );
				$temp_array[ $key ] = $nonce;
			}

			// Defining our final nonce array.
			define( 'TOPLEVEL_FINAL_NONCES_ARRAY', wp_json_encode( $temp_array ) );

		}

		/**
		 * Adding the admin js file
		 */
		public function postsaver_admin_js() {

			wp_register_script( 'postsaver_adminjs', POSTSAVER_JS_URL . 'postsaver_admin.min.js', array( 'jquery' ), POSTSAVER_VERSION_NUM, true );

			global $wpdb;

			$final_array_of_php_values = array();

			// Now grab all of our Nonces to pass to the JavaScript for the Ajax functions and merge with the Translations array.
			$final_array_of_php_values = array_merge( $final_array_of_php_values, json_decode( TOPLEVEL_FINAL_NONCES_ARRAY, true ) );

			// Adding some other individual values we may need.
			$final_array_of_php_values['POSTSAVER_ROOT_IMG_ICONS_URL']   = POSTSAVER_ROOT_IMG_ICONS_URL;
			$final_array_of_php_values['POSTSAVER_ROOT_IMG_URL']   = POSTSAVER_ROOT_IMG_URL;
			$final_array_of_php_values['FOR_TAB_HIGHLIGHT']    = admin_url() . 'admin.php';
			$final_array_of_php_values['SAVED_ATTACHEMENT_ID'] = get_option( 'media_selector_attachment_id', 0 );
			$final_array_of_php_values['SETTINGS_PAGE_URL'] = menu_page_url( 'WPBookList-Options-settings', false );
			$final_array_of_php_values['DB_PREFIX'] = $wpdb->prefix;
			$final_array_of_php_values['POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL']   = POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL;

			// Get the Ajax URL and provide it to back-end scripts.
			$temp_ajax_path = admin_url( 'admin-ajax.php' );
			// Checking $protocol in HTTP or HTTPS.
			if ( isset( $_SERVER['HTTPS'] ) && 'off' !== $_SERVER['HTTPS'] ) {
				// This is HTTPS.
				$protocol = 'https';
			} else {
				// This is HTTP.
				$protocol = 'http';
			}
			$good_ajax_url  = $protocol . strchr( $temp_ajax_path, ':' );
			$final_array_of_php_values['AJAX_URL']   = $good_ajax_url;


			// Now registering/localizing our JavaScript file, passing all the PHP variables we'll need in our $final_array_of_php_values array, to be accessed from 'wpbooklist_php_variables' object (like wpbooklist_php_variables.nameofkey, like any other JavaScript object).
			wp_localize_script( 'postsaver_adminjs', 'postSaverPhpVariables', $final_array_of_php_values );
			wp_enqueue_script( 'postsaver_adminjs' );

		}

		/**
		 * Adding the frontend js file
		 */
		public function postsaver_frontend_js() {

			global $wpdb;

			wp_register_script( 'postsaver_frontendjs', POSTSAVER_JS_URL . 'postsaver_frontend.min.js', array( 'jquery' ), POSTSAVER_VERSION_NUM, true );

			$final_array_of_php_values = array();

			// Now grab all of our Nonces to pass to the JavaScript for the Ajax functions and merge with the Translations array.
			$final_array_of_php_values = array_merge( $final_array_of_php_values, json_decode( TOPLEVEL_FINAL_NONCES_ARRAY, true ) );

			// Adding some other individual values we may need.
			$final_array_of_php_values['POSTSAVER_ROOT_IMG_ICONS_URL']   = POSTSAVER_ROOT_IMG_ICONS_URL;
			$final_array_of_php_values['POSTSAVER_ROOT_IMG_URL']   = POSTSAVER_ROOT_IMG_URL;
			$final_array_of_php_values['FOR_TAB_HIGHLIGHT']    = admin_url() . 'admin.php';
			$final_array_of_php_values['SAVED_ATTACHEMENT_ID'] = get_option( 'media_selector_attachment_id', 0 );
			$final_array_of_php_values['DB_PREFIX'] = $wpdb->prefix;
			$final_array_of_php_values['IS_USER_LOGGED_IN']   = is_user_logged_in();
			$final_array_of_php_values['USER_WPID']   = get_current_user_id();
			$final_array_of_php_values['CURRENT_POST_ID']   = get_the_ID();

			// Get the Ajax URL and provide it to front-end scripts.
			$temp_ajax_path = admin_url( 'admin-ajax.php' );
			// Checking $protocol in HTTP or HTTPS.
			if ( isset( $_SERVER['HTTPS'] ) && 'off' !== $_SERVER['HTTPS'] ) {
				// This is HTTPS.
				$protocol = 'https';
			} else {
				// This is HTTP.
				$protocol = 'http';
			}
			$good_ajax_url  = $protocol . strchr( $temp_ajax_path, ':' );
			$final_array_of_php_values['AJAX_URL']   = $good_ajax_url;

			// Get some info to provide to the front-end for the saving of posts.
			$current_user = wp_get_current_user();
			$table_name = $wpdb->prefix . 'postsaver_users';
			$user_info = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $table_name WHERE email = %s", $current_user->user_email ) );
			$final_array_of_php_values['USER_SAVED_POST_IDS']   = $user_info->savedposts;
			$final_array_of_php_values['POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL']   = POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL;

			// Now registering/localizing our JavaScript file, passing all the PHP variables we'll need in our $final_array_of_php_values array, to be accessed from 'wpbooklist_php_variables' object (like wpbooklist_php_variables.nameofkey, like any other JavaScript object).
			wp_localize_script( 'postsaver_frontendjs', 'postSaverPhpVariables', $final_array_of_php_values );

			wp_enqueue_script( 'postsaver_frontendjs' );

		}

		/**
		 * Adding the admin css file
		 */
		public function postsaver_admin_style() {

			wp_register_style( 'postsaver_adminui', POSTSAVER_CSS_URL . 'postsaver-main-admin.css', null, POSTSAVER_VERSION_NUM );
			wp_enqueue_style( 'postsaver_adminui' );

		}

		/**
		 * Adding the frontend css file
		 */
		public function postsaver_frontend_style() {

			wp_register_style( 'postsaver_frontendui', POSTSAVER_CSS_URL . 'postsaver-main-frontend.css', null, POSTSAVER_VERSION_NUM );
			wp_enqueue_style( 'postsaver_frontendui' );

		}

		/**
		 *  Function to add table names to the global $wpdb.
		 */
		public function postsaver_register_table_name() {
			global $wpdb;
			$wpdb->postsaver_settings = "{$wpdb->prefix}postsaver_settings";
			$wpdb->postsaver_users = "{$wpdb->prefix}postsaver_users";
		}

		/**
		 *  Runs once upon plugin activation and creates the table that holds info on Postsaverplugin Pages & Posts.
		 */
		public function postsaver_create_tables() {
			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			global $wpdb;
			global $charset_collate;

			// Call this manually as we may have missed the init hook.
			$this->postsaver_register_table_name();

			$sql_create_table1 = "CREATE TABLE {$wpdb->postsaver_users}
			(
				ID bigint(190) auto_increment,
				wpuserid varchar(255),
				email varchar(255),
				firstname varchar(255),
				lastname varchar(255),
				savedposts varchar(255),
				PRIMARY KEY  (ID),
				KEY email (email)
			) $charset_collate; ";

			// If table doesn't exist, create table and add initial data to it.
			$test_name = $wpdb->prefix . 'postsaver_users';
			if ( $test_name !== $wpdb->get_var( "SHOW TABLES LIKE '$test_name'" ) ) {
				dbDelta( $sql_create_table1 );
			}

			$sql_create_table2 = "CREATE TABLE {$wpdb->postsaver_settings}
			(
				ID bigint(190) auto_increment,
				dashboardurl varchar(255),
				blogpageurl varchar(255),
				PRIMARY KEY  (ID),
				KEY dashboardurl (dashboardurl)
			) $charset_collate; ";

			// If table doesn't exist, create table and add initial data to it.
			$test_name = $wpdb->prefix . 'postsaver_settings';
			if ( $test_name !== $wpdb->get_var( "SHOW TABLES LIKE '$test_name'" ) ) {
				dbDelta( $sql_create_table2 );
				$table_name = $wpdb->prefix . 'postsaver_settings';

				// Some info to add to the table upon activation.
				$blogurl = get_post_type_archive_link( 'post' );
				$insert_array = array(
					'ID' => 1,
					'blogpageurl' => get_post_type_archive_link( 'post' ),
				);
				$wpdb->insert( $table_name, $insert_array );
			}
		}

		/**
		 *  The shortcode for displaying the login form / register forms / dashboard.
		 */
		public function postsaver_login_shortcode_function() {

			ob_start();
			include_once POSTSAVER_CLASS_DIR . 'class-postsaver-dashboard-ui.php';
			$front_end_ui = new PostSaver_Dashboard_UI();
			return ob_get_clean();

		}

		/**
		 *  The code that changes page title to be the first name of the logged-in individual.
		 */
		public function postsaver_modify_account_page_title( $currentpagetitle ){
		    global $post;

		    if ( is_user_logged_in() ) {
		    	if ( 'Your Account' === $currentpagetitle ) {
		    		$current_user = wp_get_current_user();
		    		return 'Welcome ' . $current_user->first_name . '!';
		    	} else {
		    		return $currentpagetitle;
		    	}
			} else {
				return $currentpagetitle;
			}
		}


		
		/**
		 *  A function to append "login=failed" to the URL and display a message to user.
		 */
		public function postsaver_account_login_fail( $username ) {
		   $referrer = $_SERVER['HTTP_REFERER'];  // where did the post submission come from?
		   // if there's a valid referrer, and it's not the default log-in screen
		   if ( !empty($referrer) && !strstr($referrer,'wp-login') && !strstr($referrer,'wp-admin') && strstr($referrer, POSTSAVER_FRONTEND_USER_DASHBOARD_SHORTCODE_URL ) ) {
		      if ( false !== stripos( $referrer, '?id=' ) ) {
		      	$postid = explode( '=', $referrer );
		      	$referrer = str_replace('?id=' . $postid[1], '', $referrer );
		      	wp_redirect( $referrer . '?id=' . $postid[1] . '&login=failed' );
		      	exit;
		      } else {
		      	$referrer = str_replace('?login=failed', '', $referrer );
		      	wp_redirect( $referrer . '?login=failed' );  // let's append some information (login=failed) to the URL for the theme to use
		      	exit;
		      }
		      
		   }
		}

		// a Function to redirect the user after login to their dashboard.
		public function postsaver_redirect_on_login() {

			$referrer = $_SERVER['HTTP_REFERER'];
			if( ( false === stripos( $referrer, 'wp-admin' ) ) && ( false === stripos( $referrer, 'wp-login' ) ) ) {
				$referrer = str_replace('?login=failed', '', $referrer );
				$referrer = str_replace('&login=failed', '', $referrer );
				wp_redirect( $referrer );
			    exit;
			}
		}

		// A function to prevent the admin bar for subscribers on the front-end.
		function postsaver_remove_admin_bar() {
			if (!current_user_can('administrator') && !is_admin()) {
			  show_admin_bar(false);
			}
		}

	}
endif;