

<?php
/**
 * PostSaver_Dashboard_UI Class that dispalys the login form or the user dashboard - class-postsaverplugin-dashboard-ui.php
 *
 * @author   Jake Evans
 * @category Admin
 * @package  Includes/Classes
 * @version  6.1.5.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'PostSaver_Dashboard_UI', false ) ) :

	/**
	 * PostSaver_Admin_Menu Class.
	 */
	class PostSaver_Dashboard_UI {


		/**
		 * Class Constructor
		 */
		public function __construct() {

			// For grabbing an image from media library.
			wp_enqueue_media();
			wp_enqueue_script( 'password-strength-meter' );

			$this->allgeneralsettings = array();
			$this->allowed_tags = array();

			// See if we have a currently logged-in user.
			$loggedin = is_user_logged_in();

			// Calling functions in class now...
			$this->postsaver_allowed_html();
			$this->postsaver_get_general_settings();
			$this->save_post_if_in_param();

			// If user is logged in...
			if ( $loggedin ) {
				$this->stitch_logged_in_member_html();
			} else {
				$this->stitch_login_or_register_html();
			}

		}

		/**
		 * Function to specify all allowed HTML in this file.
		 */
		public function postsaver_allowed_html() {

			add_filter( 'safe_style_css', function( $styles ) {
			    $styles[] = 'display';
			    return $styles;
			} );

			$this->allowed_tags = array(
				'a' => array(
					'class' => array(),
					'href'  => array(),
					'rel'   => array(),
					'title' => array(),
				),
				'div' => array(
					'class' => array(),
					'id' => array(),
					'title' => array(),
					'style' => array(),
				),
				'p' => array(
					'class' => array(),
					'id' => array(),
					'style' => array(),
				),
				'span' => array(
					'class' => array(),
					'title' => array(),
					'style' => array(),
				),
				'button' => array(
					'class' => array(),
					'id' => array(),
				),
				'label' => array(
					'style' => array(),
					'class' => array(),
					'for' => array(),
				),
				'input' => array(
					'class' => array(),
					'id' => array(),
					'style' => array(),
					'type' => array(),
					'name' => array(),
					'value' => array(),
					'size' => array(),
					'placeholder' => array(),
				),
				'form' => array(
					'name' => array(),
					'id' => array(),
					'action' => array(),
					'method' => array(),
				),
			);
		}

		/**
		 * Function to grab all the General Settings and assign them to a class variable.
		 */
		public function postsaver_get_general_settings() {
			global $wpdb;
			$table = $wpdb->prefix . 'postsaver_settings';
			$this->allgeneralsettings = $wpdb->get_row( "SELECT * from $table" );
		}

		/**
		 * If there's a post id in the url as a parameter, grab it and see if it's saved to the user's account. if it's not, save it.
		 */

		public function save_post_if_in_param(){

			if ( false !== stripos( $_SERVER['REQUEST_URI'], 'login=failed' ) ) {
				$this->failedlogin_text = 'Whoops! Looks like you provided the wrong username or password! Please try again, or register to your right if you\'re new here!';
			}

			if ( false !== stripos( $_SERVER['REQUEST_URI'], '?id=' ) ) {

				$postid = sanitize_text_field( $_GET['id'] );
				$current_user = wp_get_current_user();
				
				global $wpdb;
				$table_name = $wpdb->prefix . 'postsaver_users';
				$user_info = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $table_name WHERE wpuserid = %s", $current_user->ID ) );

				$postids_array = explode( ',', $user_info->savedposts );
				$match = false;
				foreach( $postids_array as $postkey => $savedpostid ) {
					if ( $postid === $savedpostid ) {
						$match = true;
					}
				}

				if ( ! $match ){
					$data = array(
				        'savedposts' => $user_info->savedposts . ',' . $postid, 
				    );
				    $format = array( '%s' ); 
				    $where = array( 'wpuserid' => $current_user->ID );
				    $where_format = array( '%s' );
				    $wpdb->update( $table_name, $data, $where, $format, $where_format );
				}	
			}
		}

		/**
		 * Builds and outputs the final HTML for individuals to sign in or register.
		 */
		public function stitch_login_or_register_html() {
			$this->display_login_or_register_form();
		}

		/**
		 * Builds and outputs the final HTML for individuals who are already registered.
		 */
		public function stitch_logged_in_member_html() {
			$this->display_registered_user_dashboard();
		}

		/**
		 * The Login/Register HTML.
		 */
		public function display_login_or_register_form() {

			$args = array(
				'echo'           => false,
				'remember'       => true,
				'redirect'       => ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'],
				'form_id'        => 'postsaverplugin-dashboard-login-row-wrapper',
				'id_username'    => 'user_login',
				'id_password'    => 'user_pass',
				'id_remember'    => 'rememberme',
				'id_submit'      => 'wp-submit',
				'label_username' => __( 'Email' ),
				'label_password' => __( 'Password' ),
				'label_remember' => __( 'Remember Me' ),
				'label_log_in'   => __( 'Log In' ),
				'value_username' => '',
				'value_remember' => false
			);

			$login_register_html = '<div id="postsaverplugin-dashboard-container">
										<div id="postsaverplugin-dashboard-login-wrapper">
											<p class="postsaverplugin-tab-intro-para postsaverplugin-tab-intro-para-special-style">Already Registered? Sign in below!</p>' . wp_login_form( $args ) . '
											<div class="postsaverplugin-dashboard-login-row-response-wrapper">
												<div class="postsaverplugin-spinner" id="postsaverplugin-spinner-1"></div>
												<div class="postsaverplugin-response-div-actual-container">
									 				<p class="postsaverplugin-response-div-p" id="postsaverplugin-response-div-p-existing-login">' . $this->failedlogin_text . '</p>
									 			</div>
								 			</div>
										</div>
									<div id="postsaverplugin-not-registered-top-container">
										<p>Not Registered? Sign up below!</p>
										<div class="postsaverplugin-form-section-wrapper">
											<div class="postsaverplugin-form-section-fields-wrapper">
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<label class="postsaverplugin-form-section-fields-label">First Name</label>
													<input class="postsaverplugin-form-section-fields-input postsaverplugin-form-section-fields-input-text" id="postsaverplugin-user-firstname" type="text" placeholder="Your First Name" />
												</div>
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<label class="postsaverplugin-form-section-fields-label">Last Name</label>
													<input class="postsaverplugin-form-section-fields-input postsaverplugin-form-section-fields-input-text" id="postsaverplugin-user-lastname" type="text" placeholder="Your Last Name" />
												</div>
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<label class="postsaverplugin-form-section-fields-label">Email</label>
													<input class="postsaverplugin-form-section-fields-input postsaverplugin-form-section-fields-input-text" id="postsaverplugin-user-email" type="text" placeholder="Your Email Address" />
												</div>
											</div>
											<div class="postsaverplugin-form-section-fields-wrapper">
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<label style="position:relative; margin-left: auto;margin-right: auto;" class="postsaverplugin-form-section-fields-label">Password<button class="postsaverplugin-form-section-submit-button" id="postsaverplugin-form-section-see-new-user-password" data-visibility="hidden">View Password</button></label>
													<input class="postsaverplugin-form-section-fields-input postsaverplugin-form-section-fields-input-text" id="postsaverplugin-user-password" name="password" type="password" placeholder="Your Password" />
												</div>
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<label class="postsaverplugin-form-section-fields-label">Verify Password</label>
													<input class="postsaverplugin-form-section-fields-input postsaverplugin-form-section-fields-input-text" id="postsaverplugin-user-passwordverify" name="password_retyped" type="password" placeholder="Verify Your Password" />
												</div>
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<p style="opacity:0; display: inline-block;" id="password-strength">Password Strength is...</p>
												</div>
											</div>
											<div class="postsaverplugin-form-section-fields-wrapper">
												<div class="postsaverplugin-form-section-fields-indiv-wrapper" id="postsaverplugin-form-section-fields-indiv-wrapper-register-passwordresults" >
													<button class="postsaverplugin-form-section-submit-button" id="postsaverplugin-form-section-add-new-user-button">Register</button>
												</div>
											</div>
											<div class="postsaverplugin-form-section-fields-wrapper" id="postsaverplugin-form-section-fields-wrapper-spinner-response-area">
												<div class="postsaverplugin-form-section-fields-indiv-wrapper">
													<div class="postsaverplugin-spinner" id="postsaverplugin-spinner-create"></div>
								 					<div class="postsaverplugin-response-div-actual-container">
								 						<p class="postsaverplugin-response-div-p" id="postsaverplugin-response-div-p-new-registrant"></p>
								 					</div>
												</div>
											</div>
										</div>
									</div>
									</div>';

			echo wp_kses( $login_register_html, $this->allowed_tags );

		}

		/**
		 * The Dashboard HTML for those already registered.
		 */
		public function display_registered_user_dashboard() {

			// Get logged in user's info
			$current_user = wp_get_current_user();

			global $wpdb;
			$table_name = $wpdb->prefix . 'postsaver_users';
			// Check for duplicate email.
			$user_info = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $table_name WHERE email = %s", $current_user->user_email ) );

			$opening_html = '<div id="postsaverplugin-form-section-wrapper-forms-and-tabs-container">
												<div id="postsaverplugin-form-section-wrapper-lefthand-tabs-container">
													<div id="postsaverplugin-form-section-wrapper-lefthand-tabs-inner-wrapper">
														<div class="postsaverplugin-form-section-wrapper-lefthand-tabs-actual postsaverplugin-form-section-wrapper-lefthand-tabs-actual-accountinfo postsaverplugin-form-section-wrapper-lefthand-tabs-actual-active">
															<p>Account&nbsp;Info</p>
														</div>
														<div class="postsaverplugin-form-section-wrapper-lefthand-tabs-actual postsaverplugin-form-section-wrapper-lefthand-tabs-actual-savedposts">
															<p>Saved&nbsp;Articles</p>
														</div>
													</div>
												</div>
												<div id="postsaverplugin-form-section-wrapper-top-container">';

			$logged_in_user_dashboard_accountinfo_html = '
													<div class="postsaverplugin-form-section-wrapper postsaverplugin-form-section-wrapper-accountinfo">
														<div class="postsaverplugin-form-section-fields-wrapper">
															<div class="postsaverplugin-form-section-fields-indiv-wrapper postsaverplugin-form-section-fields-indiv-wrapper-justtext">
																<label class="postsaverplugin-form-section-fields-label">First Name</label>
																<p class="postsaverplugin-form-section-fields-label-actualvalue">' . $user_info->firstname . '</p>
															</div>
															<div class="postsaverplugin-form-section-fields-indiv-wrapper postsaverplugin-form-section-fields-indiv-wrapper-justtext">
																<label class="postsaverplugin-form-section-fields-label">Last Name</label>
																<p class="postsaverplugin-form-section-fields-label-actualvalue">' . $user_info->lastname . '</p>
															</div>
															<div class="postsaverplugin-form-section-fields-indiv-wrapper postsaverplugin-form-section-fields-indiv-wrapper-justtext">
																<label class="postsaverplugin-form-section-fields-label">Email</label>
																<p class="postsaverplugin-form-section-fields-label-actualvalue">' . $user_info->email . '</p>
															</div>
														</div>
													</div>';

			// Get all of the posts the user has saved.
			$table_name = $wpdb->prefix . 'postsaver_users';
			$userid = get_current_user_id();
			$user_info = $wpdb->get_row( $wpdb->prepare( "SELECT * FROM $table_name WHERE wpuserid = %s", $userid ) );
	
			if ( null !== $user_info->savedposts ) { 
				$postids = explode( ',', $user_info->savedposts );
				$post_html = '
					<div class="postsaverplugin-form-section-wrapper-savedposts-for-browsing">
						<p>Below are the articles and posts you\'ve saved to your account. Be sure to check back frequently for more great content!</p>
						<a href="' . $this->allgeneralsettings->blogpageurl . '">Browse Articles & Posts</a>
					</div>';

				// Reverse the Array so the newest posts are listed first.
				$postids = array_reverse( $postids );
				foreach( $postids as $id ){

					if ( '' !== $id ) {
						$title = get_post_field( 'post_title', $id );
						$featured_image = get_the_post_thumbnail( $id, 'large' );
		  				$excerpt = get_post_field( 'post_excerpt', $id );
						$post_html = $post_html . '
						<div class="postsaverplugin-savedposts-indiv-container" data-postid="' . $id . '">
							<a href="' . get_permalink( $id ) . '">
							<div class="postsaverplugin-savedposts-indiv-container-title">
								<p>' . $title . '</p>
							</div>
							<div class="postsaverplugin-savedposts-indiv-container-image">
								' . $featured_image . '
							</div>
							<div class="postsaverplugin-savedposts-indiv-container-excerpt">
								' . $excerpt . '
							</div>
							<div class="postsaverplugin-savedposts-indiv-container-readmore">

							</div>
							</a>
						</div>';
					}
				}
			} else {
				$post_html = '
				<div class="postsaverplugin-form-section-wrapper-savedposts-for-browsing">
					<p>You haven\'t saved anything yet! Click below to browse our articles and blog posts.</p>
					<a href="' . $this->allgeneralsettings->blogpageurl . '">Browse Articles & Posts</a>
				</div>';
			}

			$logged_in_user_dashboard_savedpost_html = '
													<div style="display: none;" class="postsaverplugin-form-section-wrapper postsaverplugin-form-section-wrapper-savedposts">
														' . $post_html . '
													</div>
												</div>';

			$closing_html = '</div>';


			echo wp_kses( $opening_html . $logged_in_user_dashboard_accountinfo_html . $logged_in_user_dashboard_savedpost_html . $closing_html, $this->allowed_tags );
		}

	

	}
endif;