<?php
/**
 * PostSaver Plugin
 *
 * @package     PostSaver Plugin
 * @author      Jake Evans
 * @copyright   2018 Jake Evans
 * @license     GPL-2.0+
 *
 * @wordpress-plugin
 * Plugin Name: PostSaver
 * Plugin URI: https://www.jakerevans.com/plugins/postsaver
 * Description: A Plugin allowing visitors to create an account and save blog posts for future viewing!
 * Version: 1.0.0
 * Author: Jake Evans
 * Text Domain: postsaver
 * Author URI: https://www.jakerevans.com
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $wpdb;

/* REQUIRE STATEMENTS */
	require_once 'includes/class-postsaver-general-functions.php';
	require_once 'includes/class-postsaver-ajax-functions.php';
/* END REQUIRE STATEMENTS */

/* CONSTANT DEFINITIONS */

	if ( ! defined('POSTSAVER_VERSION_NUM' ) ) {
		define( 'POSTSAVER_VERSION_NUM', '1.0.0' );
	}

	// This Extension's Version Number.
	define( 'POSTSAVER_VERSION_NUM', '1.0.0' );

	// Root plugin folder directory.
	define( 'POSTSAVER_ROOT_DIR', plugin_dir_path( __FILE__ ) );

	// Root WordPress Plugin Directory.
	define( 'POSTSAVER_ROOT_WP_PLUGINS_DIR', str_replace( '/postsaver', '', plugin_dir_path( __FILE__ ) ) );

	// Root plugin folder URL .
	define( 'POSTSAVER_ROOT_URL', plugins_url( '', __FILE__ ) . '/' );

	// Root Classes Directory.
	define( 'POSTSAVER_CLASS_DIR', POSTSAVER_ROOT_DIR . 'includes/classes/' );

	// Root REST Classes Directory.
	define( 'POSTSAVER_CLASS_REST_DIR', POSTSAVER_ROOT_DIR . 'includes/classes/rest/' );

	// Root Compatability Classes Directory.
	define( 'POSTSAVER_CLASS_COMPAT_DIR', POSTSAVER_ROOT_DIR . 'includes/classes/compat/' );

	// Root Image URL.
	define( 'POSTSAVER_ROOT_IMG_URL', POSTSAVER_ROOT_URL . 'assets/img/' );

	// Root Image iCONS URL.
	define( 'POSTSAVER_ROOT_IMG_ICONS_URL', POSTSAVER_ROOT_URL . 'assets/img/icons/' );

	// Root CSS URL.
	define( 'POSTSAVER_CSS_URL', POSTSAVER_ROOT_URL . 'assets/css/' );

	// Root JS URL.
	define( 'POSTSAVER_JS_URL', POSTSAVER_ROOT_URL . 'assets/js/' );

	// Root UI directory.
	define( 'POSTSAVER_ROOT_INCLUDES_UI', POSTSAVER_ROOT_DIR . 'includes/ui/' );

	// Nonces array.
	define( 'POSTSAVER_NONCES_ARRAY',
		wp_json_encode(array(
			'adminnonce1' => 'postsaver_save_license_key_action_callback',
			'adminnonce2' => 'postsaver_add_new_user_action_callback',
			'adminnonce3' => 'postsaver_settings_save_action_callback',
		))
	);

/* END OF CONSTANT DEFINITIONS */

/* MISC. INCLUSIONS & DEFINITIONS */

	// Loading textdomain.
	load_plugin_textdomain( 'postsaver', false, POSTSAVER_ROOT_DIR . 'languages' );

/* END MISC. INCLUSIONS & DEFINITIONS */

/* CLASS INSTANTIATIONS */

	// Call the class found in postsaverplugin-functions.php.
	$toplevel_general_functions = new PostSaver_General_Functions();

	// Call the class found in postsaverplugin-functions.php.
	$toplevel_ajax_functions = new PostSaver_Ajax_Functions();

/* END CLASS INSTANTIATIONS */


/* FUNCTIONS FOUND IN CLASS-WPPLUGIN-GENERAL-FUNCTIONS.PHP THAT APPLY PLUGIN-WIDE */

	// For the admin pages.
	add_action( 'admin_menu', array( $toplevel_general_functions, 'postsaver_jre_my_admin_menu' ) );

	// Adding the function that will take our POSTSAVER_NONCES_ARRAY Constant from above and create actual nonces to be passed to Javascript functions.
	add_action( 'init', array( $toplevel_general_functions, 'postsaver_create_nonces' ) );

	// Function that saves the main dashboard URL as a constant.
	add_action( 'init', array( $toplevel_general_functions, 'postsaver_dashboard_url_constant' ) );

	// Adding the admin js file.
	add_action( 'admin_enqueue_scripts', array( $toplevel_general_functions, 'postsaver_admin_js' ) );

	// Adding the frontend js file.
	add_action( 'wp_enqueue_scripts', array( $toplevel_general_functions, 'postsaver_frontend_js' ) );

	// Adding the admin css file for this extension.
	add_action( 'admin_enqueue_scripts', array( $toplevel_general_functions, 'postsaver_admin_style' ) );

	// Adding the Front-End css file for this extension.
	add_action( 'wp_enqueue_scripts', array( $toplevel_general_functions, 'postsaver_frontend_style' ) );

	// Function to add table names to the global $wpdb.
	add_action( 'admin_footer', array( $toplevel_general_functions, 'postsaver_register_table_name' ) );

	// Creates default table upon activation.
	register_activation_hook( __FILE__, array( $toplevel_general_functions, 'postsaver_create_tables' ) );

	// Creates default table upon activation.
	register_activation_hook( __FILE__, array( $toplevel_general_functions, 'postsaver_create_initial_dashboard_page' ) );

	// Adding the front-end login / dashboard shortcode.
	add_shortcode( 'postsaver_login_shortcode', array( $toplevel_general_functions, 'postsaver_login_shortcode_function' ) );

	// Function that logs in a user automatically after they've first registered.
	add_action( 'after_setup_theme', array( $toplevel_general_functions, 'postsaver_autologin_after_registering' ) );

	// Function to make the account page say, "Welcome [userfirstname]!"
	add_action( 'the_title', array( $toplevel_general_functions, 'postsaver_modify_account_page_title' ) );

	// A function to append "login=failed" to the URL and display a message to user.
	add_action( 'wp_login_failed', array( $toplevel_general_functions, 'postsaver_account_login_fail' ) );

	// a Function to redirect the user after login to their dashboard.
	add_action( 'wp_login', array( $toplevel_general_functions, 'postsaver_redirect_on_login' ) );

	// A function to prevent the admin bar for subscribers on the front-end.
	add_action( 'after_setup_theme', array( $toplevel_general_functions, 'postsaver_remove_admin_bar' ) );

	// Adding the function that will allow the displaying of the Adminpointers when question marks are hovered over.
	add_action( 'admin_footer', array( $toplevel_general_functions, 'postsaver_jre_admin_pointers_javascript' ) );


/* END OF FUNCTIONS FOUND IN CLASS-WPPLUGIN-GENERAL-FUNCTIONS.PHP THAT APPLY PLUGIN-WIDE */

/* FUNCTIONS FOUND IN CLASS-WPPLUGIN-AJAX-FUNCTIONS.PHP THAT APPLY PLUGIN-WIDE */

// Function for adding a new user from the frontend. Accomplished by actual website visitor. 
add_action( 'wp_ajax_nopriv_postsaver_add_new_user_action', array( $toplevel_ajax_functions, 'postsaver_add_new_user_action_callback' ) );

// Function to save the general settings on the "wp-admin/admin.php?page=PostSaver-Options-settings" page.
add_action( 'wp_ajax_postsaver_settings_save_action', array( $toplevel_ajax_functions, 'postsaver_settings_save_action_callback' ) );


/* END OF FUNCTIONS FOUND IN CLASS-WPPLUGIN-AJAX-FUNCTIONS.PHP THAT APPLY PLUGIN-WIDE */



function ajax_check_user_logged_in() {
    echo is_user_logged_in()?'yes':'no';
    die();
}
add_action('wp_ajax_is_user_logged_in', 'ajax_check_user_logged_in');
add_action('wp_ajax_nopriv_is_user_logged_in', 'ajax_check_user_logged_in');











